edgeagent

package
v0.1.0-alpha Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 20, 2025 License: Apache-2.0 Imports: 15 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Agent

type Agent struct {
	// contains filtered or unexported fields
}

Agent is the core struct for the edge agent business logic.

func (*Agent) Run

func (a *Agent) Run(ctx context.Context) error

Run starts the main loop of the agent and handles graceful shutdown.

type Config

type Config struct {
	// Identity
	VehicleID string

	// MQTT Config
	MqttBroker      string
	MqttUsername    string
	MqttPassword    string
	MqttTopicPrefix string
}

func (*Config) NewAgent

func (cfg *Config) NewAgent() (*Agent, error)

Jump to